@@ -1,10 +1,10 @@
-# -*- coding: utf-8 -*-
 from plone.app.theming.interfaces import IThemeSettings
 from plone.registry.interfaces import IRegistry
 from Products.Five.browser import BrowserView
 from zope.component import getUtility
 
 import dateutil
+import time
 import wsgiref
 
 class CustomCSSView(BrowserView):
