@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from App.config import getConfiguration
 from logging import getLogger
 from plone.app.theming import utils
@@ -24,7 +23,7 @@ def invalidateCache(settings, event):
 
 
 @implementer(IThemingPolicy)
-class ThemingPolicy(object):
+class ThemingPolicy:
 
     def __init__(self, request):
         """Adapt IRequest.
@@ -55,8 +54,6 @@ class ThemingPolicy(object):
     def getCurrentTheme(self):
         """The name of the current theme."""
         settings = self.getSettings()
-        if not settings.rules:
-            return None
         if settings.currentTheme:
             return settings.currentTheme
 
@@ -87,7 +84,7 @@ class ThemingPolicy(object):
 
         if not settings:
             settings = self.getSettings()
-        if settings is None or not settings.enabled or not settings.rules:
+        if settings is None or not settings.enabled:
             return False
 
         server_url = self.request.get('SERVER_URL')
@@ -117,7 +114,7 @@ class ThemingPolicy(object):
     def getCacheKey(self, theme=None):
         if not theme:
             theme = self.getCurrentTheme()
-        key = "%s::%s" % (getSite().absolute_url(), theme)
+        key = f"{getSite().absolute_url()}::{theme}"
         return key
 
     def getCacheStorage(self):
@@ -178,7 +175,7 @@ class ThemingPolicy(object):
         cache.updateTheme(themeObj)
 
 
-class ThemeCache(object):
+class ThemeCache:
     """Simple cache for the transform and theme
     """
 
