@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from App.config import getConfiguration
 from diazo.compiler import compile_theme
 from lxml import etree
@@ -14,16 +13,15 @@ from plone.app.theming.utils import InternalResolver
 from plone.app.theming.utils import PythonResolver
 from plone.app.theming.utils import resolvePythonURL
 from plone.registry.interfaces import IRegistry
-from plone.testing.z2 import Browser
+from plone.testing.zope import Browser
 from Products.CMFCore.Expression import Expression
 from Products.CMFCore.Expression import getExprContext
 from Products.CMFCore.utils import getToolByName
-from six.moves.urllib.error import HTTPError
+from urllib.error import HTTPError
 from zope.component import getUtility
 
 import os.path
 import re
-import six
 import transaction
 import unittest
 
@@ -39,7 +37,7 @@ class TestCase(unittest.TestCase):
         self.settings = getUtility(IRegistry).forInterface(IThemeSettings)
 
         self.settings.enabled = False
-        self.settings.rules = u'python://plone.app.theming/tests/rules.xml'
+        self.settings.rules = 'python://plone.app.theming/tests/rules.xml'
         self.settings.parameterExpressions = {
             'stringParam': 'string:string param value',
             'boolParam': 'python:False',
@@ -130,15 +128,15 @@ class TestCase(unittest.TestCase):
         applyTheme(theme)
         self.assertEqual(
             self.settings.rules,
-            u'/++theme++plone.app.theming.tests/rules.xml'
+            '/++theme++plone.app.theming.tests/rules.xml'
         )
         self.assertEqual(
             self.settings.currentTheme,
-            u"plone.app.theming.tests"
+            "plone.app.theming.tests"
         )
         self.assertEqual(
             self.settings.doctype,
-            u"<!DOCTYPE html>"
+            "<!DOCTYPE html>"
         )
         transaction.commit()
 
@@ -155,7 +153,7 @@ class TestCase(unittest.TestCase):
         self.assertTrue("This is the theme" in browser.contents)
 
         # Doctype
-        self.assertTrue(re.match("<!DOCTYPE html>\s+<html", browser.contents))
+        self.assertTrue(re.match(r"<!DOCTYPE html>\s+<html", browser.contents))
 
     def test_theme_enabled_query_string_off_switch(self):
         app = self.layer['app']
@@ -212,25 +210,15 @@ class TestCase(unittest.TestCase):
         # The theme
         self.assertFalse("This is the theme" in browser.contents)
 
-    def test_internal_resolver(self):
-        compiler_parser = etree.XMLParser()
-        compiler_parser.resolvers.add(InternalResolver())
-        # We can use a sub-package or a directory since tests is a python
-        # package
-        theme = resolvePythonURL(
-            u'python://plone.app.theming.tests/theme.html'
-        )
-        rules = resolvePythonURL(u'python://plone.app.theming/tests/rules.xml')
-        compile_theme(rules, theme, compiler_parser=compiler_parser)
-
     def test_python_resolver(self):
-        compiler_parser = etree.XMLParser()
-        compiler_parser.resolvers.add(PythonResolver())
+        # The rules contain a python:// link, so we need a python resolver.
+        parser = etree.HTMLParser()
+        parser.resolvers.add(PythonResolver())
         theme = resolvePythonURL(
-            u'python://plone.app.theming.tests/theme.html'
+            'python://plone.app.theming.tests/theme.html'
         )
-        rules = resolvePythonURL(u'python://plone.app.theming/tests/rules.xml')
-        compile_theme(rules, theme, compiler_parser=compiler_parser)
+        rules = resolvePythonURL('python://plone.app.theming/tests/rules.xml')
+        compile_theme(rules, theme, parser=parser)
 
     def test_theme_stored_in_plone_site(self):
         app = self.layer['app']
@@ -244,7 +232,7 @@ class TestCase(unittest.TestCase):
             portal.manage_addDTMLMethod('theme.html', file=theme_contents)
 
         # These paths should be relative to the Plone site root
-        self.settings.rules = u'/rules.xml'
+        self.settings.rules = '/rules.xml'
         self.settings.enabled = True
 
         transaction.commit()
@@ -273,7 +261,7 @@ class TestCase(unittest.TestCase):
             portal.manage_addDTMLMethod('theme.html', file=theme_contents)
 
         # These paths should be relative to the Plone site root
-        self.settings.rules = u'/rules.xml'
+        self.settings.rules = '/rules.xml'
         self.settings.enabled = True
 
         from Products.SiteAccess import VirtualHostMonster
@@ -286,7 +274,7 @@ class TestCase(unittest.TestCase):
         suffix = portalURL.split('/')[-1]
 
         vhostURL = (
-            "{0:s}/VirtualHostBase/http/example.org:80/{1:s}/VirtualHostRoot"
+            "{:s}/VirtualHostBase/http/example.org:80/{:s}/VirtualHostRoot"
             "/_vh_fizz/_vh_buzz/_vh_fizzbuzz/".format(prefix, suffix)
         )
 
@@ -321,7 +309,7 @@ class TestCase(unittest.TestCase):
         portal = self.layer['portal']
 
         self.settings.enabled = True
-        self.settings.absolutePrefix = u'http://example.com'
+        self.settings.absolutePrefix = 'http://example.com'
 
         transaction.commit()
 
@@ -338,7 +326,7 @@ class TestCase(unittest.TestCase):
         portal = self.layer['portal']
 
         self.settings.enabled = True
-        self.settings.absolutePrefix = u'/foo'
+        self.settings.absolutePrefix = '/foo'
 
         transaction.commit()
 
@@ -360,14 +348,14 @@ class TestCase(unittest.TestCase):
         transaction.commit()
 
         self.settings.enabled = True
-        self.settings.absolutePrefix = u'/foo'
+        self.settings.absolutePrefix = '/foo'
 
         portalURL = portal.absolute_url()
         prefix = '/'.join(portalURL.split('/')[:-1])
         suffix = portalURL.split('/')[-1]
 
         vhostURL = (
-            "{0:s}/VirtualHostBase/http/example.org:80/{1:s}/VirtualHostRoot"
+            "{:s}/VirtualHostBase/http/example.org:80/{:s}/VirtualHostRoot"
             "/_vh_fizz/_vh_buzz/_vh_fizzbuzz/".format(prefix, suffix)
         )
 
@@ -387,7 +375,7 @@ class TestCase(unittest.TestCase):
         portal = self.layer['portal']
 
         self.settings.enabled = True
-        self.settings.rules = u"invalid"
+        self.settings.rules = "invalid"
 
         transaction.commit()
 
@@ -539,7 +527,7 @@ class TestCase(unittest.TestCase):
         portal = self.layer['portal']
 
         setRoles(portal, TEST_USER_ID, ('Manager',))
-        portal.invokeFactory('Folder', 'news', title=u"News")
+        portal.invokeFactory('Folder', 'news', title="News")
         wftool = getToolByName(portal, "portal_workflow")
         wftool.doActionFor(portal.news, action='publish')
         setRoles(portal, TEST_USER_ID, ('Member',))
@@ -576,7 +564,7 @@ class TestCase(unittest.TestCase):
         portal = self.layer['portal']
 
         self.settings.enabled = True
-        self.settings.rules = u'python://plone.app.theming/tests/paramrules.xml'  # noqa
+        self.settings.rules = 'python://plone.app.theming/tests/paramrules.xml'  # noqa
         self.settings.parameterExpressions = {
             'stringParam': 'string:string param value',
             'boolParam': 'python:False',
@@ -633,7 +621,7 @@ class TestCase(unittest.TestCase):
         browser.addHeader('Accept', 'text/html')
         error = None
         try:
-            browser.open('{0:s}/404_page'.format(portal.absolute_url()))
+            browser.open(f'{portal.absolute_url():s}/404_page')
         except HTTPError as e:
             error = e
         self.assertEqual(error.code, 404)
@@ -646,7 +634,7 @@ class TestCase(unittest.TestCase):
         portal = self.layer['portal']
 
         self.settings.enabled = True
-        self.settings.rules = u'python://plone.app.theming/tests/paramrules.xml'  # noqa
+        self.settings.rules = 'python://plone.app.theming/tests/paramrules.xml'  # noqa
         self.settings.parameterExpressions = {
             'stringParam': 'string:string param value',
             'boolParam': 'python:False',
@@ -660,7 +648,7 @@ class TestCase(unittest.TestCase):
         browser.addHeader('Accept', 'text/html')
         error = None
         try:
-            browser.open('{0:s}/404_page'.format(portal.absolute_url()))
+            browser.open(f'{portal.absolute_url():s}/404_page')
         except HTTPError as e:
             error = e
         self.assertEqual(error.code, 404)
@@ -709,7 +697,7 @@ class TestCase(unittest.TestCase):
         error = None
         try:
             browser.open(
-                '{0:s}/widget/oauth_login/info.txt'.format(
+                '{:s}/widget/oauth_login/info.txt'.format(
                     portal['subfolder'].absolute_url()
                 )
             )
@@ -793,7 +781,7 @@ class TestCase(unittest.TestCase):
             portal['subfolder'].manage_addDTMLMethod('alpha', file=two)
 
         # Set up transformation
-        self.settings.rules = u'python://plone.app.theming/tests/includes.xml'
+        self.settings.rules = 'python://plone.app.theming/tests/includes.xml'
         self.settings.enabled = True
 
         transaction.commit()
@@ -834,7 +822,7 @@ class TestCase(unittest.TestCase):
             portal.manage_addDTMLMethod('french', file=french)
 
         # Set up transformation
-        self.settings.rules = u'python://plone.app.theming/tests/nonascii.xml'
+        self.settings.rules = 'python://plone.app.theming/tests/nonascii.xml'
         self.settings.enabled = True
 
         transaction.commit()
@@ -847,10 +835,7 @@ class TestCase(unittest.TestCase):
 
         browser.open(portal.absolute_url())
         # browser.contents is always string.  On Py 2 this means bytes, on Py 3 text.
-        if six.PY2:
-            self.assertIn(b'<div id="content">Actualit\xc3\xa9s</div>', browser.contents)
-        else:
-            self.assertIn(u'<div id="content">Actualit\xe9s</div>', browser.contents)
+        self.assertIn('<div id="content">Actualit\xe9s</div>', browser.contents)
 
     def test_css_js_includes(self):
 
@@ -858,7 +843,7 @@ class TestCase(unittest.TestCase):
         portal = self.layer['portal']
 
         self.settings.enabled = True
-        self.settings.rules = u'/++theme++plone.app.theming.tests/css-js.xml'
+        self.settings.rules = '/++theme++plone.app.theming.tests/css-js.xml'
         transaction.commit()
 
         browser = Browser(app)
@@ -880,17 +865,14 @@ class TestCase(unittest.TestCase):
         portal = self.layer['portal']
 
         self.settings.enabled = True
-        self.settings.rules = u'/++theme++plone.app.theming.tests/nonascii.xml'
+        self.settings.rules = '/++theme++plone.app.theming.tests/nonascii.xml'
         transaction.commit()
 
         browser = Browser(app)
         browser.open(portal.absolute_url())
 
         # browser.contents is always string.  On Py 2 this means bytes, on Py 3 text.
-        if six.PY2:
-            self.assertIn(b'<div>N\xc3\xbamero uno</div>', browser.contents)
-        else:
-            self.assertIn(u'<div>N\xfamero uno</div>', browser.contents)
+        self.assertIn('<div>N\xfamero uno</div>', browser.contents)
 
 
     def test_theme_enabled_query_string_debug_switch(self):
