@@ -1,12 +1,38 @@
-# -*- coding: utf-8 -*-
+from plone.app.theming.testing import THEMING_FUNCTIONAL_TESTING
 from plone.app.theming.testing import THEMING_INTEGRATION_TESTING
+from plone.app.theming.utils import applyTheme
 from plone.app.theming.utils import extractThemeInfo
+from plone.app.theming.utils import getTheme
+from plone.app.testing import SITE_OWNER_NAME
+from plone.app.testing import SITE_OWNER_PASSWORD
+from plone.testing.zope import Browser
 
 import os.path
+import tempfile
+import transaction
 import unittest
 import zipfile
 
 
+# We will try to let the rules file point to a theme on the file system.
+# For security reasons, this should not work.
+# This is one of the fixes from PloneHotFix20210518.
+RULES = """<?xml version="1.0" encoding="UTF-8"?>
+<rules
+    xmlns="http://namespaces.plone.org/diazo"
+    xmlns:css="http://namespaces.plone.org/diazo/css"
+    xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
+        <theme href="{0}" />
+</rules>
+"""
+# The theme will contain a message:
+MESSAGE = "Hello from a temporary directory."
+# We have a sample theme file here:
+HERE = os.path.dirname(__file__)
+PACKAGE_THEME_FILENAME = "package_theme.txt"
+PACKAGE_THEME = os.path.join(HERE, PACKAGE_THEME_FILENAME)
+
+
 class TestIntegration(unittest.TestCase):
 
     layer = THEMING_INTEGRATION_TESTING
@@ -118,8 +144,8 @@ class TestIntegration(unittest.TestCase):
 
         settings = getUtility(IRegistry).forInterface(IThemeSettings, False)
 
-        settings.rules = u"/++theme++foo/rules.xml"
-        settings.absolutePrefix = u"/++theme++foo"
+        settings.rules = "/++theme++foo/rules.xml"
+        settings.absolutePrefix = "/++theme++foo"
         settings.parameterExpressions = {}
 
         applyTheme(None)
@@ -138,7 +164,7 @@ class TestIntegration(unittest.TestCase):
 
         settings = getUtility(IRegistry).forInterface(IThemeSettings, False)
         settings.enabled = True
-        settings.rules = u"/++theme++foo/rules.xml"
+        settings.rules = "/++theme++foo/rules.xml"
 
         request = self.layer['request']
 
@@ -154,7 +180,7 @@ class TestIntegration(unittest.TestCase):
 
         settings = getUtility(IRegistry).forInterface(IThemeSettings, False)
         settings.enabled = True
-        settings.rules = u"/++theme++foo/rules.xml"
+        settings.rules = "/++theme++foo/rules.xml"
 
         request = self.layer['request']
         request.set('BASE1', 'http://nohost/path/to/site')
@@ -180,11 +206,11 @@ class TestIntegration(unittest.TestCase):
         self.assertTrue(title in titles)
 
         theme = getTheme(themeName)
-        expected_prefix = u"/++%s++%s" % (THEME_RESOURCE_NAME,
+        expected_prefix = "/++{}++{}".format(THEME_RESOURCE_NAME,
                                           title.replace(" ", "-"))
         self.assertEqual(theme.absolutePrefix, expected_prefix)
 
-        expected_rules = u"/++%s++%s/%s" % (THEME_RESOURCE_NAME,
+        expected_rules = "/++{}++{}/{}".format(THEME_RESOURCE_NAME,
                                             title.replace(" ", "-"),
                                             RULE_FILENAME)
         self.assertEqual(theme.rules, expected_rules)
@@ -203,11 +229,11 @@ class TestIntegration(unittest.TestCase):
         self.assertTrue(title in titles)
 
         theme = getTheme(themeName)
-        expected_prefix = u"/++%s++%s" % (THEME_RESOURCE_NAME,
+        expected_prefix = "/++{}++{}".format(THEME_RESOURCE_NAME,
                                           title.replace(" ", "-"))
         self.assertEqual(theme.absolutePrefix, expected_prefix)
 
-        expected_rules = u"/++%s++%s/%s" % (THEME_RESOURCE_NAME,
+        expected_rules = "/++{}++{}/{}".format(THEME_RESOURCE_NAME,
                                             title.replace(" ", "-"),
                                             RULE_FILENAME)
         self.assertEqual(theme.rules, expected_rules)
@@ -215,19 +241,24 @@ class TestIntegration(unittest.TestCase):
         self.assertEqual(theme.enabled_bundles, ['plone'])
         self.assertEqual(theme.disabled_bundles, ['foobar'])
 
-        expected_dev_css = u"/++%s++%s/less/barceloneta.plone.less" % (
+        expected_dev_css = "/++{}++{}/css/barceloneta.css".format(
             THEME_RESOURCE_NAME, title.replace(" ", "-"))
-        expected_prod_css = u"/++%s++%s/less/barceloneta-compiled.css" % (
+        expected_prod_css = "/++{}++{}/css/barceloneta.min.css".format(
             THEME_RESOURCE_NAME, title.replace(" ", "-"))
-        expected_tinymce = u"/++%s++%s/less/barceloneta-compiled.css" % (
+        expected_tinymce_content_css = "/++{}++{}/css/barceloneta.min.css".format(
             THEME_RESOURCE_NAME, title.replace(" ", "-"))
+        expected_tinymce_styles_css = (
+            "/++{}++{}/css/custom-format-styles.css".format(
+                THEME_RESOURCE_NAME, title.replace(" ", "-"))
+        )
         self.assertEqual(theme.development_css, expected_dev_css)
         self.assertEqual(theme.production_css, expected_prod_css)
-        self.assertEqual(theme.tinymce_content_css, expected_tinymce)
+        self.assertEqual(theme.tinymce_content_css, expected_tinymce_content_css)
+        self.assertEqual(theme.tinymce_styles_css, expected_tinymce_styles_css)
 
-        expected_dev_js = u"/++%s++%s/script.js" % (
+        expected_dev_js = "/++{}++{}/script.js".format(
             THEME_RESOURCE_NAME, title.replace(" ", "-"))
-        expected_prod_js = u"/++%s++%s/script.min.js" % (
+        expected_prod_js = "/++{}++{}/script.min.js".format(
             THEME_RESOURCE_NAME, title.replace(" ", "-"))
         self.assertEqual(theme.development_js, expected_dev_js)
         self.assertEqual(theme.production_js, expected_prod_js)
@@ -246,11 +277,11 @@ class TestIntegration(unittest.TestCase):
         self.assertTrue(title in titles)
 
         theme = getTheme(themeName)
-        expected_prefix = u"/++%s++%s" % (THEME_RESOURCE_NAME,
+        expected_prefix = "/++{}++{}".format(THEME_RESOURCE_NAME,
                                           title.replace(" ", "-"))
         self.assertEqual(theme.absolutePrefix, expected_prefix)
 
-        expected_rules = u"/++%s++%s/%s" % (THEME_RESOURCE_NAME,
+        expected_rules = "/++{}++{}/{}".format(THEME_RESOURCE_NAME,
                                            title.replace(" ", "-"),
                                            RULE_FILENAME)
         self.assertEqual(theme.rules, expected_rules)
@@ -258,19 +289,24 @@ class TestIntegration(unittest.TestCase):
         self.assertEqual(theme.enabled_bundles, ['plone'])
         self.assertEqual(theme.disabled_bundles, ['foobar'])
 
-        expected_dev_css = u"++%s++%s/less/barceloneta.plone.less" % (
+        expected_dev_css = "++{}++{}/css/barceloneta.css".format(
             THEME_RESOURCE_NAME, title.replace(" ", "-"))
-        expected_prod_css = u"++%s++%s/less/barceloneta-compiled.css" % (
+        expected_prod_css = "++{}++{}/css/barceloneta.min.css".format(
             THEME_RESOURCE_NAME, title.replace(" ", "-"))
-        expected_tinymce = u"++%s++%s/less/barceloneta-compiled.css" % (
+        expected_tinymce_content_css = "++{}++{}/css/barceloneta.min.css".format(
             THEME_RESOURCE_NAME, title.replace(" ", "-"))
+        expected_tinymce_styles_css = (
+            "++{}++{}/css/custom-format-styles.css".format(
+                THEME_RESOURCE_NAME, title.replace(" ", "-"))
+        )
         self.assertEqual(theme.development_css, expected_dev_css)
         self.assertEqual(theme.production_css, expected_prod_css)
-        self.assertEqual(theme.tinymce_content_css, expected_tinymce)
+        self.assertEqual(theme.tinymce_content_css, expected_tinymce_content_css)
+        self.assertEqual(theme.tinymce_styles_css, expected_tinymce_styles_css)
 
-        expected_dev_js = u"++%s++%s/script.js" % (
+        expected_dev_js = "++{}++{}/script.js".format(
             THEME_RESOURCE_NAME, title.replace(" ", "-"))
-        expected_prod_js = u"++%s++%s/script.min.js" % (
+        expected_prod_js = "++{}++{}/script.min.js".format(
             THEME_RESOURCE_NAME, title.replace(" ", "-"))
         self.assertEqual(theme.development_js, expected_dev_js)
         self.assertEqual(theme.production_js, expected_prod_js)
@@ -283,17 +319,17 @@ class TestIntegration(unittest.TestCase):
             createThemeFromTemplate(title, description,
                                             baseOn="another-theme")
         except UnicodeEncodeError:
-            self.fail(msg=u"Unicode Encode Error")
+            self.fail(msg="Unicode Encode Error")
 
     def test_createThemeFromTemplate_ja_unicode_title(self):
         from plone.app.theming.utils import createThemeFromTemplate
-        title = u"copy of test theme by 日本語"
-        description = u"test theme by 日本語"
+        title = "copy of test theme by 日本語"
+        description = "test theme by 日本語"
         try:
             createThemeFromTemplate(title, description,
                                             baseOn="another-theme")
         except UnicodeEncodeError:
-            self.fail(msg=u"Unicode Encode Error")
+            self.fail(msg="Unicode Encode Error")
 
 
 class TestUnit(unittest.TestCase):
@@ -311,7 +347,7 @@ class TestUnit(unittest.TestCase):
             theme = extractThemeInfo(zf)
 
             self.assertEqual(theme.__name__, 'default_rules')
-            self.assertEqual(theme.rules, u'/++theme++default_rules/rules.xml')
+            self.assertEqual(theme.rules, '/++theme++default_rules/rules.xml')
             self.assertEqual(theme.absolutePrefix, '/++theme++default_rules')
 
     def test_extractThemeInfo_manifest_rules(self):
@@ -334,7 +370,7 @@ class TestUnit(unittest.TestCase):
             self.assertEqual(theme.__name__, 'manifest_prefix')
             self.assertEqual(
                 theme.rules,
-                u'/++theme++manifest_prefix/rules.xml'
+                '/++theme++manifest_prefix/rules.xml'
             )
             self.assertEqual(theme.absolutePrefix, '/foo')
             self.assertEqual(theme.title,  'Test theme')
@@ -348,7 +384,7 @@ class TestUnit(unittest.TestCase):
             self.assertEqual(theme.__name__, 'manifest_default_rules')
             self.assertEqual(
                 theme.rules,
-                u'/++theme++manifest_default_rules/rules.xml'
+                '/++theme++manifest_default_rules/rules.xml'
             )
             self.assertEqual(
                 theme.absolutePrefix,
@@ -365,7 +401,7 @@ class TestUnit(unittest.TestCase):
             self.assertEqual(theme.__name__, 'manifest_preview')
             self.assertEqual(
                 theme.rules,
-                u'/++theme++manifest_preview/rules.xml'
+                '/++theme++manifest_preview/rules.xml'
             )
             self.assertEqual(
                 theme.absolutePrefix,
@@ -405,7 +441,7 @@ class TestUnit(unittest.TestCase):
             theme = extractThemeInfo(zf)
 
             self.assertEqual(theme.__name__, 'default_rules')
-            self.assertEqual(theme.rules, u'/++theme++default_rules/rules.xml')
+            self.assertEqual(theme.rules, '/++theme++default_rules/rules.xml')
             self.assertEqual(theme.absolutePrefix, '/++theme++default_rules')
 
     def test_extractThemeInfo_with_subdirectories(self):
@@ -417,6 +453,138 @@ class TestUnit(unittest.TestCase):
             self.assertEqual(theme.__name__, 'subdirectories')
             self.assertEqual(
                 theme.rules,
-                u'/++theme++subdirectories/rules.xml'
+                '/++theme++subdirectories/rules.xml'
             )
             self.assertEqual(theme.absolutePrefix, '/++theme++subdirectories')
+
+
+class TestAttackVector(unittest.TestCase):
+    layer = THEMING_FUNCTIONAL_TESTING
+
+    def setUp(self):
+        self.portal = self.layer["portal"]
+        rules_fd, self.rules_file = tempfile.mkstemp(
+            suffix=".xml", prefix="rules", text=True
+        )
+        with open(self.rules_file, "w") as myfile:
+            myfile.write(MESSAGE)
+
+    def tearDown(self):
+        os.remove(self.rules_file)
+
+    def get_admin_browser(self):
+        browser = Browser(self.layer["app"])
+        browser.handleErrors = False
+        browser.addHeader(
+            "Authorization",
+            f"Basic {SITE_OWNER_NAME}:{SITE_OWNER_PASSWORD}",
+        )
+        return browser
+
+    def get_anon_browser(self):
+        browser = Browser(self.layer["app"])
+        browser.handleErrors = False
+        return browser
+
+    def test_failing_file_protocol_resolver(self):
+        from plone.app.theming.utils import FailingFileProtocolResolver
+
+        resolver = FailingFileProtocolResolver()
+        with self.assertRaises(ValueError):
+            resolver.resolve("file:///etc/passwd", "public_id", "context")
+        with self.assertRaises(ValueError):
+            resolver.resolve(
+                "file:" + os.path.relpath("/etc/passwd"), "public_id", "context"
+            )
+        with self.assertRaises(ValueError):
+            resolver.resolve("file://" + self.rules_file, "public_id", "context")
+        with self.assertRaises(ValueError):
+            resolver.resolve(
+                "file:" + os.path.relpath(self.rules_file), "public_id", "context"
+            )
+
+    def test_failing_file_system_resolver(self):
+        from plone.app.theming.utils import FailingFileSystemResolver
+
+        resolver = FailingFileSystemResolver()
+        with self.assertRaises(ValueError):
+            resolver.resolve("/etc/passwd", "public_id", "context")
+        with self.assertRaises(ValueError):
+            resolver.resolve(os.path.relpath("/etc/passwd"), "public_id", "context")
+        with self.assertRaises(ValueError):
+            resolver.resolve(self.rules_file, "public_id", "context")
+        with self.assertRaises(ValueError):
+            resolver.resolve(os.path.relpath(self.rules_file), "public_id", "context")
+
+    def new_theme(self, theme_path):
+        from plone.app.theming.utils import createThemeFromTemplate
+        from plone.resource.directory import PersistentResourceDirectory
+
+        # Start with an empty theme.
+        # Pass title and description
+        theme_name = createThemeFromTemplate("Security", "")
+        theme = getTheme(theme_name)
+        directory = PersistentResourceDirectory()
+        directory.writeFile(
+            "/".join(["theme", theme_name, "rules.xml"]), RULES.format(theme_path)
+        )
+        applyTheme(theme)
+        transaction.commit()
+
+    def test_theme_file_system_absolute(self):
+        self.new_theme(self.rules_file)
+        browser = self.get_anon_browser()
+        browser.open(self.portal.absolute_url())
+        self.assertNotIn(MESSAGE, browser.contents)
+
+    def test_theme_file_system_relative(self):
+        self.new_theme(os.path.relpath(self.rules_file))
+        browser = self.get_anon_browser()
+        browser.open(self.portal.absolute_url())
+        self.assertNotIn(MESSAGE, browser.contents)
+
+    def test_theme_file_protocol_absolute(self):
+        self.new_theme("file://" + self.rules_file)
+        browser = self.get_anon_browser()
+        browser.open(self.portal.absolute_url())
+        self.assertNotIn(MESSAGE, browser.contents)
+
+    def test_theme_file_protocol_relative(self):
+        # This is actually handled by the InternalResolver.
+        # Well, in fact it gives an error because it cannot resolve it in the Plone Site:
+        # AttributeError: 'PersistentResourceDirectory' object has no attribute 'getPhysicalPath'
+        # This can be seen when previewing the theme in the theme editor.
+        self.new_theme("file:" + os.path.relpath(self.rules_file))
+        browser = self.get_anon_browser()
+        browser.open(self.portal.absolute_url())
+        self.assertNotIn(MESSAGE, browser.contents)
+
+    def test_theme_python_protocol(self):
+        # Since our example rules file is in a Python package,
+        # we can use the python resolver to access it.
+        # I don't think we can avoid this.
+        self.new_theme(
+            "python://plone.app.theming/tests/" + PACKAGE_THEME_FILENAME
+        )
+        with open(PACKAGE_THEME) as myfile:
+            contents = myfile.read()
+        browser = self.get_anon_browser()
+        browser.open(self.portal.absolute_url())
+        self.assertIn(contents, browser.contents)
+
+    def test_available_themes(self):
+        """Test that all available themes render properly.
+
+        Our security fixes should not break them.
+        """
+        from plone.app.theming.utils import getAvailableThemes
+
+        for theme in getAvailableThemes():
+            applyTheme(theme)
+            transaction.commit()
+            # Can you view the portal anonymously?
+            browser = self.get_anon_browser()
+            browser.open(self.portal.absolute_url())
+            # Can you view the portal as admin anonymously?
+            browser = self.get_admin_browser()
+            browser.open(self.portal.absolute_url())
