@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from App.config import getConfiguration
 from lxml import etree
 from os import environ
@@ -26,7 +25,7 @@ LOGGER = logging.getLogger('plone.app.theming')
 
 @implementer(ITransform)
 @adapter(Interface, IThemingLayer)
-class ThemeTransform(object):
+class ThemeTransform:
     """Late stage in the 8000's transform chain. When plone.app.blocks is
     used, we can benefit from lxml parsing having taken place already.
     """
@@ -69,6 +68,9 @@ class ThemeTransform(object):
         if settings is None:
             return None
 
+        if not settings.rules:
+            return None
+
         if not policy.isThemeEnabled():
             return None
 
@@ -119,6 +121,16 @@ class ThemeTransform(object):
         except (AttributeError, TypeError, etree.ParseError):
             return None
 
+    def transformBytes(self, result, encoding):
+        try:
+            result = result.decode(encoding)
+        except UnicodeDecodeError:
+            # This is probably a file or an image
+            # FIXME probably we do not event want to apply
+            # this transform for files and images
+            pass
+        return self.transformIterable([result], encoding)
+
     def transformString(self, result, encoding):
         return self.transformIterable([result], encoding)
 
@@ -130,11 +142,12 @@ class ThemeTransform(object):
         """
         # Obtain settings. Do nothing if not found
         policy = theming_policy(self.request)
-        settings = policy.getSettings()
-        if settings is None:
-            return None
         if not policy.isThemeEnabled():
             return None
+        settings = policy.getSettings()
+        if settings is None or not settings.rules:
+            # if there is no rules file given, do not try to transform
+            return None
         result = self.parseTree(result)
         if result is None:
             return None
