@@ -1,9 +1,8 @@
-# -*- coding: utf-8 -*-
 from plone.app.theming.interfaces import THEME_RESOURCE_NAME
 from plone.app.theming.utils import theming_policy
 from plone.resource.traversal import ResourceTraverser
 from plone.resource.utils import queryResourceDirectory
-from six.moves import urllib
+from urllib.parse import quote
 from zExceptions import NotFound
 
 
@@ -27,7 +26,7 @@ class ThemeTraverser(ResourceTraverser):
             name = self.current_theme()
 
         # Note: also fixes possible unicode problems
-        name = urllib.parse.quote(name)
+        name = quote(name)
 
         res = queryResourceDirectory(self.name, name)
         if res is not None:
